GraphVelo Tutorials
====================

This section contains various tutorials showcasing GraphVelo analysis with :mod:`graphvelo`.

.. toctree::
    :maxdepth: 1

    tutorial_for_scvelo
    tutorial_hcmv
    figure2_analytical_manifold
    figure2_dyngen
    variable_rate_simulation
    benchmark